Starrr, for jQuery

### Starrr

##### Click to rate:

Your rating was .

##### Advanced:

##### Why?

There are other libraries out there, but none that approach the level clarity and conciseness that I wanted. Starrr is less than 75 lines of code -- you can understand the entirety of its source code in about a minute.

##### Dependencies

jQuery.

I'm using Bootstrap + Font Awesome to render the stars, but you're more than welcome to use something else.